CHANGELOG
=========

### upcoming

- nothing currently planned

### 1.1.1 - 2021-03-16

- reduce minimum `pandas` dependency to `1.1.0` to avoid dependency clash

### 1.1.0 - 2021-03-16

- fixed locating of resource file

### 1.0.6 - 2021-03-16

- fixed setup.py

### 1.0.5 - 2021-03-16

- added lato.zip to manifest

### 1.0.4 - 2021-03-15

- fixing lato.zip provision as an asset

### 1.0.3 - 2021-03-15

- fix issue with font provided as asset

### 1.0.2 - 2021-03-15

- bundle lato.zip with the module rather than downloading when necessary
- update dependencies

### 1.0.1

- updated dependencies

### 1.0.0

- formatted code using [black](https://pypi.org/project/black/)

### 0.0.1

- initial version of `apolitical-data-viz`
